@@ -47,7 +47,9 @@ gene_associate <- function(reaction_table, gene_table, expression_flux_function
   assert_that(gene_table %has_name% 'presence')
   
   reaction_table %>%
-    mutate(present = gene_eval(.data$geneAssociation, gene_table$name, gene_table$presence)) %>%
-    mutate(uppbnd = .data$uppbnd*expression_flux_function(.data$present),
-            lowbnd = .data$lowbnd*expression_flux_function(.data$present))
+    mutate(present = gene_eval(.data$geneAssociation, gene_table$name, gene_table$presence),
+           present = if_else(is.na(.data$present), 1, .data$present),
+           uppbnd = .data$uppbnd*expression_flux_function(.data$present),
+           lowbnd = .data$lowbnd*expression_flux_function(.data$present)
+    )
 }
\ No newline at end of file
