@@ -1,15 +1,24 @@
 context("ROI_plugins")
-library(tidyverse)
+suppressMessages(library(tidyverse))
+suppressMessages(library(ROI.plugin.ecos))
 
 data("ecoli_core")
 data("iJO1366")
 
+suppressMessages(
+  walk(
+    setdiff(
+      intersect(
+        ROI::ROI_registered_solvers(),
+        ROI::ROI_installed_solvers()
+      ), 
+      "ROI.plugin.nlminb"
+    ), 
+    requireNamespace)
+)
+
 test_that("same results on ecoli_core", {
-  skip('fails for some plugins')
-  
-  ROI::ROI_installed_solvers() %>%
-    map(library, character.only=TRUE)
-  
+
   mod <- ecoli_core %>%
     reactiontbl_to_expanded() %>%
     expanded_to_ROI()
@@ -25,13 +34,9 @@ test_that("same results on ecoli_core", {
     
 })
 
-test_that("same results on ecoli_core", {
-  skip('fails for some plugins')
-  
-  ROI::ROI_installed_solvers() %>%
-    map(library, character.only=TRUE)
-  
-  mod <- iJO1366 %>%
+test_that("same results on iJO1366", {
+
+    mod <- iJO1366 %>%
     reactiontbl_to_expanded() %>%
     expanded_to_ROI()
   
@@ -41,7 +46,7 @@ test_that("same results on ecoli_core", {
     keep(~is.null(.$error)) %>%
     map('result')%>%
     map(ROI::solution) %>%
-    walk(expect_length, n=95) %>%
+    walk(expect_length, n=2583) %>%
     walk(~ expect_true(all(is.finite(.))))
   
 })
